@@ -2,4 +2,4 @@
 """satellite_weather_downloader Weather Collection Python package"""
 # TODO: Docstrings
 from .extract_reanalysis import *
-from .utils import *
+from .reanalysis import *
